@@ -49,7 +49,9 @@
 
 package com.openexchange.mobile.api.facade.auth;
 
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 
 import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
 
@@ -86,4 +88,10 @@ public class SessionData {
     @NonFinal
     String forwardedFor;
 
+    Map<String, String> properties = new HashMap<>();
+
+    public void setProperty(String name, String value) {
+        properties.put(name, value);
+    }
+
 }
