@@ -116,21 +116,18 @@ public abstract class AbstractConnector<T> implements Connector<T, T> {
 
     @Override
     public T execute() {
-        try {
-            CloseableHttpClient httpClient = configuration.getHttpClient();
-            HttpUriRequest request = createRequest();
-            HttpClientContext context = HttpClientContext.create();
-            if (sessionData != null) {
-                CookieStore cookieStore = configuration.getCookieStore();
-                for (Cookie cookie : sessionData.getCookies()) {
-                    cookieStore.addCookie(cookie);
-                }
-                context.setCookieStore(cookieStore);
+        CloseableHttpClient httpClient = configuration.getHttpClient();
+        HttpUriRequest request = createRequest();
+        HttpClientContext context = HttpClientContext.create();
+        if (sessionData != null) {
+            CookieStore cookieStore = configuration.getCookieStore();
+            for (Cookie cookie : sessionData.getCookies()) {
+                cookieStore.addCookie(cookie);
             }
-            CloseableHttpResponse response = httpClient.execute(request, context);
-            T responseBody = handleResponse(response);
-            response.close();
-            return responseBody;
+            context.setCookieStore(cookieStore);
+        }
+        try (CloseableHttpResponse response = httpClient.execute(request, context)) {
+            return handleResponse(response);
         } catch (Exception e) {
             log.error("Failed to execute request", e);
             throw ApiFacadeException.internalServerError(e);
