@@ -82,11 +82,17 @@ public class Account {
 
     private final boolean canSend;
 
-    @NonNull
-    private final List<Folder> folders;
+    private final String rootFolderId;
 
-    @NonNull
-    private final StandardFolders standardFolders;
+    private final String archiveFolderId;
+
+    private List<Folder> folders;
+
+    private StandardFolders standardFolders;
+
+    public Account(AccountMto accountMto, UserMto userMto, String defaultSendAddress) {
+        this(accountMto, userMto, defaultSendAddress, null);
+    }
 
     public Account(AccountMto accountMto, UserMto userMto, String defaultSendAddress, List<Folder> folders) {
         id = accountMto.getId();
@@ -110,13 +116,23 @@ public class Account {
             aliases = relaceAddress(accountMto.getAliases(), defaultSendAddress, accountPrimaryAddress);
         }
         canSend = "0".equals(accountMto.getId()) || !StringUtils.isEmpty(accountMto.getTransportUrl());
-        /* Java8: Use with Java 8.
-        List<FolderCto> folders = folderMtos.stream()
-                .map(folderMto -> new FolderCto(folderMto.getId(), folderMto.getParentId(), folderMto.getName(), 0, 0, 0, 0))
-                .collect(Collectors.toList());
-        */
+        rootFolderId = accountMto.getRootFolderId();
+        archiveFolderId = accountMto.getArchiveFolderId();
+        if (folders != null) {
+            /* Java8: Use with Java 8.
+            List<FolderCto> folders = folderMtos.stream()
+                    .map(folderMto -> new FolderCto(folderMto.getId(), folderMto.getParentId(), folderMto.getName(), 0, 0, 0, 0))
+                    .collect(Collectors.toList());
+            */
+            this.folders = folders;
+            standardFolders = createStandardFolders(folders);
+        }
+    }
+
+    public Account withFolders(List<Folder> folders) {
         this.folders = folders;
         standardFolders = createStandardFolders(folders);
+        return this;
     }
 
     private StandardFolders createStandardFolders(List<Folder> folders) {
@@ -167,4 +183,8 @@ public class Account {
         });
     }
 
+    public boolean isPrimaryAccount() {
+        return "0".equals(id);
+    }
+
 }
