@@ -79,6 +79,10 @@ public class Mail {
     @NonNull
     private final String id;
 
+    private String rootMailId;
+
+    private String folderId;
+
     private final MailFlags flags;
 
     private final Integer color;
