@@ -279,4 +279,8 @@ public class RequestUtil {
         }
     }
 
+    public static boolean getBooleanParameter(Boolean currentValue, boolean defaultValue) {
+        return currentValue == null ? defaultValue : currentValue.booleanValue();
+    }
+
 }
